@@ -8,20 +8,22 @@ from __future__ import annotations
 
 import sys
 import logging
-from typing import TYPE_CHECKING, Any, Callable, Generic, NamedTuple
+from typing import TYPE_CHECKING, Any, Generic, NamedTuple, TypeAlias
 from weakref import ReferenceType, ref
 from warnings import warn
 from functools import partial
+from collections import deque
+from collections.abc import Callable
 
 from . import errors as e
 from . import generators, postgres, pq
-from .abc import PQGen, PQGenConn, Query
+from .abc import PQGen, PQGenConn, QueryNoTemplate
 from .sql import SQL, Composable
 from ._tpc import Xid
 from .rows import Row
 from .adapt import AdaptersMap
 from ._enums import IsolationLevel
-from ._compat import Deque, LiteralString, Self, TypeAlias, TypeVar
+from ._compat import LiteralString, Self, TypeVar
 from .pq.misc import connection_summary
 from ._preparing import PrepareManager
 from ._capabilities import capabilities
@@ -113,7 +115,7 @@ class BaseConnection(Generic[Row]):
 
         # Gather notifies when the notifies() generator is not running.
         # It will be set to None during `notifies()` generator run.
-        self._notifies_backlog: Deque[Notify] | None = Deque()
+        self._notifies_backlog: deque[Notify] | None = deque()
 
         wself = ref(self)
         pgconn.notice_handler = partial(BaseConnection._notice_handler, wself)
@@ -125,6 +127,8 @@ class BaseConnection(Generic[Row]):
 
         self._pipeline: BasePipeline | None = None
 
+        # Time when the connection was created (currently only used by the pool)
+        self._created_at: float
         # Time after which the connection should be closed
         self._expire_at: float
 
@@ -439,7 +443,7 @@ class BaseConnection(Generic[Row]):
         return conn
 
     def _exec_command(
-        self, command: Query, result_format: pq.Format = TEXT
+        self, command: QueryNoTemplate, result_format: pq.Format = TEXT
     ) -> PQGen[PGresult | None]:
         """
         Generator to send a command and receive the result to the backend.
