@@ -20,18 +20,18 @@ DBAPI-defined Exceptions are defined in the following hierarchy::
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Callable, NoReturn, Sequence
+from typing import TYPE_CHECKING, Any, NoReturn, TypeAlias, TypeGuard
 from asyncio import CancelledError
 from dataclasses import dataclass, field, fields
+from collections.abc import Callable, Sequence
 
 from .pq.abc import PGconn, PGresult
-from ._compat import TypeAlias, TypeGuard
 from .pq._enums import ConnStatus, DiagnosticField, PipelineStatus, TransactionStatus
 
 if TYPE_CHECKING:
     from .pq.misc import ConninfoOption, PGnotify
 
-ErrorInfo: TypeAlias = "PGresult | dict[int, bytes | None] | None"
+ErrorInfo: TypeAlias = PGresult | dict[int, bytes | None] | None
 
 _sqlcodes: dict[str, type[Error]] = {}
 
@@ -61,6 +61,7 @@ class FinishedPGconn:
     error_message: bytes = b""
     _encoding: str = "utf-8"
     protocol_version: int = 0
+    full_protocol_version: int = 0
     server_version: int = 0
 
     backend_pid: int = 0
